<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Controller;

// Import framework stuff
use Org\Mxchange\CoreFramework\Generic\FrameworkException;
use Org\Mxchange\CoreFramework\Resolver\Controller\ControllerResolver;

/**
 * This exception is thrown when the default controller is missing
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class DefaultControllerException extends FrameworkException {
	/**
	 * The super constructor for all exceptions
	 *
	 * @param	$resolverInstance	An instance of a resolver class
	 * @param	$code				An optional code for better debugging
	 * @return	void
	 */
	public function __construct (ControllerResolver $resolverInstance, $code) {
		// Prepare the message
		$message = sprintf('[%s:%d] Cannot resolve default controller <span class="exception_reason">(%s)</span>. Maybe missing?',
			$resolverInstance->__toString(),
			$this->getLine(),
			$resolverInstance->getClassName()
		);

		// Set extra data
		$this->setExtraData($resolverInstance->getClassName() . ':' . $this->getLine());

		// Call parent contructor with message
		parent::__construct($message, $code);
	}

}
